--- qpy/QtCore/orig.qpycore_public_api.cpp 2016-04-24 12:55:17.000000000 +0200
+++ qpy/QtCore/qpycore_public_api.cpp 2016-06-15 21:44:57.000000000 +0200
#include "qpycore_types.h"
// A replacement for PyErr_Print() that passes the exception to qFatal().
#if PY_MAJOR_VERSION >= 3
PyErr_Restore(exception, value, traceback);
// This will be passed to qFatal() if we can't get the detailed text.
QByteArray message("Unhandled Python exception");
// Extract the detailed text if it was redirected.
// Strip the text as qFatal() likes to add a newline.
PyObject *stripped = PyObject_CallMethod(text,
CONST_CAST("strip"), NULL);
- // qFatal() may not call abort.
+ // qCritical() will not call abort.
- qFatal("%s", message.data());
+ qCritical("%s", message.data());
@@
#include "qpycore_types.h"
-// A replacement for PyErr_Print() that passes the exception to qFatal().
+// A replacement for PyErr_Print() that passes the exception to qCritical().
#if PY_MAJOR_VERSION >= 3
PyErr_Restore(exception, value, traceback);
@@
#if PY_MAJOR_VERSION >= 3
PyErr_Restore(exception, value, traceback);
- // This will be passed to qFatal() if we can't get the detailed text.
+ // This will be passed to qCritical() if we can't get the detailed text.
QByteArray message("Unhandled Python exception");
// Extract the detailed text if it was redirected.
@@
QByteArray message("Unhandled Python exception");
// Extract the detailed text if it was redirected.
- // Strip the text as qFatal() likes to add a newline.
+ // Strip the text as qCritical() likes to add a newline.
PyObject *stripped = PyObject_CallMethod(text,
CONST_CAST("strip"), NULL);